==> elasticsearch_1.4.5%2Bdfsg.orig.tar.xz: elasticsearch-1.4.5/src/main/java/org/elasticsearch/index/cache/filter/FilterCache.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.cache.filter;

import org.apache.lucene.search.Filter;
import org.elasticsearch.common.component.CloseableComponent;
import org.elasticsearch.index.IndexComponent;
import org.elasticsearch.index.service.IndexService;

/**
 *
 */
public interface FilterCache extends IndexComponent, CloseableComponent {

    static class EntriesStats {
        public final long sizeInBytes;
        public final long count;

        public EntriesStats(long sizeInBytes, long count) {
            this.sizeInBytes = sizeInBytes;
            this.count = count;
        }
    }

    // we need to "inject" the index service to not create cyclic dep
    void setIndexService(IndexService indexService);

    String type();

    Filter cache(Filter filterToCache);

    void clear(Object reader);

    void clear(String reason);

    void clear(String reason, String[] keys);
}

==> elasticsearch_1.6.0%2Bdfsg.orig.tar.xz: elasticsearch-1.6.0/src/main/java/org/elasticsearch/index/cache/filter/FilterCache.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.cache.filter;

import org.apache.lucene.search.Filter;
import org.elasticsearch.index.IndexComponent;
import org.elasticsearch.index.IndexService;

import java.io.Closeable;

/**
 *
 */
public interface FilterCache extends IndexComponent, Closeable {

    static class EntriesStats {
        public final long sizeInBytes;
        public final long count;

        public EntriesStats(long sizeInBytes, long count) {
            this.sizeInBytes = sizeInBytes;
            this.count = count;
        }
    }

    // we need to "inject" the index service to not create cyclic dep
    void setIndexService(IndexService indexService);

    String type();

    Filter cache(Filter filterToCache);

    void clear(Object reader);

    void clear(String reason);

    void clear(String reason, String[] keys);
}
